@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2018 Maxime DOYEN
+ *	Copyright (C) 1995-2019 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -129,7 +129,7 @@ ofx_proc_statement_cb(const struct OfxStatementData data, ImportContext *ctx)
 {
 	DB( g_print("** ofx_proc_statement_cb()\n") );
 
-#ifdef MYDEBUG
+#if MYDEBUG == 1
 	if(data.ledger_balance_date_valid==true)
 	{
 	struct tm temp_tm;
